Table status functions now use dm_bdevname(), which displays the
major:minor in the same format as the 2.4 version of device-mapper.
--- diff/drivers/md/dm-linear.c	2003-06-30 10:07:21.000000000 +0100
+++ source/drivers/md/dm-linear.c	2003-08-01 10:52:37.000000000 +0100
@@ -88,7 +88,7 @@
 
 	case STATUSTYPE_TABLE:
 		snprintf(result, maxlen, "%s " SECTOR_FORMAT,
-			 bdevname(lc->dev->bdev, b), lc->start);
+			 dm_bdevname(lc->dev->bdev, b), lc->start);
 		break;
 	}
 	return 0;
--- diff/drivers/md/dm-stripe.c	2003-08-01 10:00:22.000000000 +0100
+++ source/drivers/md/dm-stripe.c	2003-08-01 10:59:13.000000000 +0100
@@ -201,7 +201,7 @@
 			offset +=
 			    snprintf(result + offset, maxlen - offset,
 				     " %s " SECTOR_FORMAT,
-		       bdevname(sc->stripe[i].dev->bdev, b),
+				     dm_bdevname(sc->stripe[i].dev->bdev, b),
 				     sc->stripe[i].physical_start);
 		}
 		break;
--- diff/drivers/md/dm.c	2003-08-01 09:59:06.000000000 +0100
+++ source/drivers/md/dm.c	2003-08-01 11:00:09.000000000 +0100
@@ -905,6 +905,13 @@
 	return test_bit(DMF_SUSPENDED, &md->flags);
 }
 
+const char *dm_bdevname(struct block_device *bdev, char *buffer)
+{
+        sprintf(buffer, "%03d:%03d",
+		MAJOR(bdev->bd_dev), MINOR(bdev->bd_dev));
+        return buffer;
+}
+
 struct block_device_operations dm_blk_dops = {
 	.open = dm_blk_open,
 	.release = dm_blk_close,
@@ -922,3 +929,5 @@
 MODULE_DESCRIPTION(DM_NAME " driver");
 MODULE_AUTHOR("Joe Thornber <thornber@sistina.com>");
 MODULE_LICENSE("GPL");
+
+EXPORT_SYMBOL(dm_bdevname);
--- diff/drivers/md/dm.h	2003-07-31 12:39:05.000000000 +0100
+++ source/drivers/md/dm.h	2003-08-01 10:58:18.000000000 +0100
@@ -152,6 +152,11 @@
 }
 
 /*
+ * Similar to bdevname.
+ */
+const char *dm_bdevname(struct block_device *bdev, char *buffer);
+
+/*
  * The device-mapper can be driven through one of two interfaces;
  * ioctl or filesystem, depending which patch you have applied.
  */
